==> aliyun-python-sdk-reid-1.1.6.tar.gz: aliyun-python-sdk-reid-1.1.6/aliyunsdkreid/request/v20190928/DescribeOverviewDataRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkreid.endpoint import endpoint_data

class DescribeOverviewDataRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'reid', '2019-09-28', 'DescribeOverviewData')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Date(self):
		return self.get_body_params().get('Date')

	def set_Date(self,Date):
		self.add_body_params('Date', Date)

	def get_StoreIds(self):
		return self.get_body_params().get('StoreIds')

	def set_StoreIds(self,StoreIds):
		self.add_body_params('StoreIds', StoreIds)

==> aliyun-python-sdk-reid-1.1.8.tar.gz: aliyun-python-sdk-reid-1.1.8/aliyunsdkreid/request/v20190928/DescribeOverviewDataRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkreid.endpoint import endpoint_data

class DescribeOverviewDataRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'reid', '2019-09-28', 'DescribeOverviewData','1.1.8')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Date(self):
		return self.get_body_params().get('Date')

	def set_Date(self,Date):
		self.add_body_params('Date', Date)

	def get_StoreIds(self):
		return self.get_body_params().get('StoreIds')

	def set_StoreIds(self,StoreIds):
		self.add_body_params('StoreIds', StoreIds)
